local addon = ...;
local L = RAT_Locals;
local RAT = RAT;
local _G = _G;

local escapeCodes = {};
escapeCodes.SUCCESS = "|cFF00FF00";
escapeCodes.FAIL = "|cFFFF0000";

local ccOptions = CreateFrame("Frame", "RAT_CC_Options", InterfaceOptionsFramePanelContainer);
ccOptions.name = "Command Center";
ccOptions.parent = "Raid Attendance Tracker";
ccOptions:Hide();

local addonText = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
addonText:SetText(L.ADDON_FULL);
addonText:SetPoint("TOP", 0, -16);

local version = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
version:SetText(L.ADDON_VERSION);
version:SetPoint("TOPLEFT", 450, -32);

local author = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
author:SetText(L.ADDON_AUTHOR);
author:SetPoint("TOPLEFT", 450, -16);

local title = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
title:SetText(L.OPTIONS_COMMAND_CENTER_TITLE);
title:SetPoint("TOPLEFT", 16, -16);

local infoText = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight");
infoText:SetText();
infoText:SetPoint("TOPLEFT", 40, -85);
infoText:SetWordWrap(true);
infoText:SetJustifyV("TOP");
infoText:SetJustifyH("LEFT");
infoText:SetSize(520, 320);

local undoButton = CreateFrame("Button", "RAT_UndoButton", ccOptions, "UIMenuButtonStretchTemplate");
undoButton:SetSize(130,50);
undoButton:SetPoint("TOPLEFT", 50, -100);
undoButton:SetText(L.OPTIONS_UNDO_BUTTON);
undoButton:SetScript("OnClick", function(self)
	local lastAttending = RAT:GetLastAttending();
	local lastAbsent = RAT:GetLastAbsent();
	local lastAmount = RAT:GetLastAmount();
	if ((next(lastAttending) or next(lastAbsent)) and lastAmount) then
		RAT:Undo(lastAttending, lastAbsent, lastAmount);
	else
		DEFAULT_CHAT_FRAME:AddMessage(escapeCodes.FAIL .. L.ADDON .. L.ERROR_UNDO);
	end
end);

local skipButton = CreateFrame("Button", "RAT_UndoButton", ccOptions, "UIMenuButtonStretchTemplate");
skipButton:SetSize(130,50);
skipButton:SetPoint("TOPLEFT", 50, -170);
skipButton:SetText(L.OPTIONS_SKIP_BUTTON);
skipButton:SetScript("OnClick", function(self)
	StaticPopup_Show ("RAT_SKIP_BUTTON");
end);

local setupButton = CreateFrame("Button", "RAT_SetupButton", ccOptions, "UIMenuButtonStretchTemplate");
setupButton:SetSize(130,50);
setupButton:SetPoint("TOPLEFT", 50, -240);
setupButton:SetText(L.OPTIONS_SETUP_BUTTON);
setupButton:SetScript("OnClick", function(self)
	StaticPopup_Show ("RAT_SETUP_BUTTON");
end);

local deleteButton = CreateFrame("Button", "RAT_DeleteButton", ccOptions, "UIMenuButtonStretchTemplate");
deleteButton:SetSize(130,50);
deleteButton:SetPoint("TOPLEFT", 50, -310);
deleteButton:SetText(L.OPTIONS_DELETE_BUTTON);
deleteButton:SetScript("OnClick", function(self)
	StaticPopup_Show ("RAT_DELETE_BUTTON");
end);

StaticPopupDialogs["RAT_SKIP_BUTTON"] = {
	text = "Are you sure you want to skip the current or coming raid?",
	button1 = "Yes",
	button2 = "No",
	OnAccept = function()
		RAT:SkipToNextRaidDay();
		RAT:BroadcastSummary();
		RAT_SavedData.Bench = {};
		RAT_SavedData.Summary = {};
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/
};

StaticPopupDialogs["RAT_SETUP_BUTTON"] = {
	text = "Are you sure you want to start the setup? It will reset all settings except alts and the attendance database.",
	button1 = "Yes",
	button2 = "No",
	OnAccept = function()
		RAT_SavedOptions.AwardStart = true;
		RAT_SavedOptions.Frequency = 60;
		RAT_SavedOptions.RankingAlgo = "RAT-Algorithm";
		RAT_SavedOptions.PunishCalendar = false;
		RAT_SavedOptions.RaiderRanks = {};
		RAT_SavedData.SetupCompleted = false;
		RAT_SavedData.NextAward = 0;
		RAT:StartSetup();
		InterfaceOptionsFrame:Hide();
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/
};

StaticPopupDialogs["RAT_DELETE_BUTTON"] = {
	text = "Are you sure you want to delete all data? If so type DELETE below. WARNING: This can not be undone.",
	button1 = "Confirm",
	button2 = "Cancel",
	hasEditBox = true,
	showAlert = true,
	OnShow = function(self, data)
		self.button1:Disable();
	end,
	OnAccept = function(self, data, data2)
		for i = 1, GetNumGuildMembers() do
			local isEligible = RAT:Eligible(i);
			local name = Ambiguate(GetGuildRosterInfo(i), "short");
			local hasMain = RAT:GetMain(name);
			RAT_SavedData.Attendance = {};
			if (isEligible or hasMain) then
				if (isEligible and not hasMain) then
					RAT:InitPlayer(name);
					RAT:UpdateNote(name, i);
				elseif (hasMain) then
					GuildRosterSetPublicNote(i, "R:99 AP:0 0% M:0 S:0/3");
				end
			else
				local note = select(8, GetGuildRosterInfo(i));
				if (note:find("R:") and note:find("AP:") and note:find("M:") and note:find("S:") and note:find("%%")) then
					GuildRosterSetOfficerNote(i, "");
					GuildRosterSetPublicNote(i, "");
				end
			end
		end
		RAT:Sync();
		SendChatMessage(L.ADDON .. Ambiguate(UnitName("player"), "short") .. L.SYSTEM_DELETED_DATA, "GUILD");
	end,
	EditBoxOnTextChanged = function(self, data)
		local input = self:GetText();
		if (input == "DELETE") then
			self:GetParent().button1:Enable();
		else
			self:GetParent().button1:Disable();
		end
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/
};

InterfaceOptions_AddCategory(ccOptions);